Biobox provides a collection of data structures and methods for loading, manipulating and analyzing atomistic and pseudoatomistic structures.

See more at https://github.com/degiacom/biobox
With the documentation at https://degiacom.github.io/biobox/
And a tutorial at https://github.com/degiacom/biobox_notebook
